pub enum Kind {
Attribute,
CAttribute,
Builtin,
Feature,
Extension,
}Expand description
What kind of thing a row of the matrix describes.
The kind is part of the identity of a row, because deprecated is both a GNU attribute
and a C23 one and the two are answered by different operators with different values.
Variants
Attribute
__attribute__((x)) and [[gnu::x]], asked about with __has_attribute.
CAttribute
A standard [[x]] attribute, asked about with __has_c_attribute.
Builtin
__builtin_x, asked about with __has_builtin.
Feature
A language or preprocessor feature, asked about with __has_feature.
Extension
A GNU extension to the language, asked about with __has_extension.