pub fn has_extension(name: &str) -> u32
What __has_extension(name) answers.
__has_extension(name)
GCC treats the two as the same question and so do we: a feature that is available is available whether or not the mode it is asked in makes it standard.